@@ -208,7 +208,12 @@ def init_twisted_greenlet():
 
 def stop_twisted_greenlet():
     if _instances.gr_twisted:
-        _instances.reactor.stop()
+        try:
+            _instances.reactor.stop()
+        except error.ReactorNotRunning:
+            # Sometimes the reactor is stopped before we get here.  For
+            # example, this can happen in response to a SIGINT in some cases.
+            pass
         _instances.gr_twisted.switch()
 
 
